title1 'Primary Biliary Cirrhosis';

data PBC;
   infile 'pbc.dat';
   input case survival status drug age sex asictes hepmega spiders edema bilirubin 
      cholest albumin copper phosph SGOT triglicer platelets prothrom stage;
   label
      case      = 'case number'
      survival  = 'survival in days'
      status    = '0=censored, 1=censored due to liver tx, 2=death'
      drug      = '1= D-penicillamine, 2=placebo'
      age       = 'age in days'
      sex       = '0=male, 1=female'
      asictes   = 'presence of asictes: 0=no 1=yes'
      hepmega   = 'presence of hepatomegaly: 0=no 1=yes'
      spiders   = 'presence of spiders  0=no 1=yes'
      edema     = '0=no edema; .5 = edema present resolved; 1 = edema despite therapy' 
      bilirubin = 'serum bilirubin in mg/dl' 
      cholest   = 'serum cholesterol in mg/dl'
      albumin   = 'albumin in gm/dl' 
      copper    = 'urine copper in ug/day' 
      phosph    = 'alkaline phosphatase in U/liter' 
      SGOT      = 'SGOT in U/ml' 
      triglicer = 'triglicerides in mg/dl' 
      platelets = 'platelets per cubic ml / 1000' 
	  prothrom  = 'prothrombin time in seconds' 
	  stage     = 'histologic stage of disease'
   ;
run;

proc print;
run;

proc means;
run;


proc phreg;
   model survival * status (1,2) = drug age sex asictes hepmega spiders edema bilirubin 
      cholest albumin copper phosph SGOT triglicer platelets prothrom stage;
run;
