options linesize = 75 pagesize=50 center;

title1 'Data on low birth weight infants';
data regn;
   infile 'birthwt.dat';
   input headcirc  length  gestage  birthwt  momage  toxemia;
   label
      headcirc = 'head circumference'
	  gestage  = 'gestational age'
	  birthwt  = 'birth weight'
	  momage   = 'mother''s age'
	  toxemia  = 'indication of toxemia';
run;

proc print; /* Always print out everything after the data step */
run;

proc gplot data=regn;
   plot birthwt * length;
   plot birthwt * momage;
   plot birthwt * headcirc;
run;

proc reg;
   model birthwt = length;
run;

title2 'Selecting the best of many possible regression models';
proc reg;
   model birthwt =  headcirc  length  gestage  momage  toxemia
         / selection=cp adjrsq r best= 5;
run;

title2 'Forward stepwise regression method';
proc reg;
   model birthwt =  headcirc  length  gestage  momage  toxemia
         / selection=f;
run;

title2 'Backward stepwise regression method';
proc reg;
   model birthwt =  headcirc  length  gestage  momage  toxemia
         / selection=b;
run;

proc plot;
   plot birthwt * length;
run;
proc reg data=birthwt;
   model birthwt =  headcirc  length  gestage  momage  toxemia
         / partial;
run;



ods trace off;
title1 ' ';
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
proc reg data=birthwt;
   model birthwt =  length headcirc gestage  momage  toxemia 
         / influence partial pcorr1 pcorr2 p r i ;
   ods output OutputStatistics = restemp;
run;quit;
data res1;
   set restemp;
   res1=Residual;
   birthwt=DepVar;
   keep res1 birthwt;
   run;
proc print data=res1; 
run;
proc reg data=birthwt;
   model length =  headcirc gestage  momage  toxemia
         / r;
   ods output OutputStatistics=res2;
run;

data combo;
   set res1;
   set res2;
   merge;
run;

proc print data=combo;
run;

proc plot data=combo;
   plot res1 * residual;
run;
options nocenter;
proc print data=combo noobs;
   var residual res1;
run;
proc corr data=birthwt;
  var birthwt length;

options nocenter;
proc print data=birthwt noobs;
var length birthwt;
run;
proc corr data=combo;
  var res1 residual;
run;

quit;
