options linesize = 65 pagesize=50 center;

title1 'Gasoline consumption and price in several countries';
data gasoline;
   input price consume name $ 21-32;
   logcon=log(consume);
   datalines;
       6.66   1.9   Norway     
       6.55   2.3   Netherlands
       6.17   1.2   Britain    
       5.98   1.4   Germany    
       5.94   1.4   Italy      
       5.68   1.4   France     
       3.50   7.3   Singapore  
       3.35   0.5   Brazil     
       3.29   0.1   India      
       3.20   0.8   Mexico     
       3.13   0.4   S Africa   
       2.26   2.9   US         
       2.05   0.8   Russia     
       1.78   0.2   China      
       1.48   0.1   Nigeria    
       0.47   0.8   Iran       
   run;

proc print;  /* Always a good idea */
run;

title2 'Model price using consumption';
proc gplot;
   plot  price * consume;
run;
quit;

proc reg data=gasoline;
   model price = consume;
run;


title2 'Model price from log-consumption'; 
proc reg data=gasoline;
    model price = logcon;
run;

proc gplot;
   plot  price * logcon;
run;
quit;


   /* Fit a LOESS smooth fit to these data */


proc sort data=gasoline;
   by consume;
run;

title2 'A LOESS smooth fit and CI for these data'; 
proc loess data=gasoline;
   model price = logcon / 
     details(OutputStatistics ModelSummary) clm residual; 
   ods output  OutputStatistics = smoothfit; 
run;

proc print data=smoothfit;
  id obs; /* print obs column only once */
run;

/* Plot observed and fitted LOESS model */ 

proc gplot data=smoothfit;
   axis1 label=(angle=90 rotate=0);
   symbol1 color=black value=dot ;   
   symbol2 color=black interpol=spline value=none;   
   symbol3 color=black interpol=spline value=none;  
   symbol4 color=black interpol=spline value=none;
 
   plot (DepVar Pred LowerCL UpperCL) * logcon /
      vaxis=axis1 hm=3 vm=3 overlay name='gasprice'; 
run;
quit; 

title2 'Compare several LOESS smoothing parameters';

proc loess data=gasoline;
   model price = logcon / details(OutputStatistics) 
         residual smooth=.35 .5 .7 .9 ;
   ods output  OutputStatistics = smoothfit4;
run;

proc print data=smoothfit4;
  id obs; /* print obs column only once */
run;

/* Present all four fitted and observed in one figure */

goptions  nodisplay; 
proc gplot data=smoothfit4; 
   by SmoothingParameter; 
   axis1 label=(angle=90 rotate=0);
   symbol1 color=black value=dot ;   
   symbol2 color=black interpol=spline value=none;  
   plot DepVar*logcon=1 Pred*logcon / 
      vaxis=axis1 hm=3 vm=3 overlay name='fit';
run;
quit; 
 
goptions display; 
proc greplay nofs tc=sashelp.templt template=l2r2; 
   igout gseg;
   treplay 1:fit16 2:fit17 3:fit18 4:fit19;
run;
quit;


