options linesize=75 pagesize=55;

title1 'Stanford heart transplant survival data';
data heart;
   input id year age cens surv prior tstatus ;
   label
      id     = 'patient identifier'
      year   = 'year enrolled'
      age    = 'patient age'
      cens   = 'censoring indicator'
      prior  = 'any prior surgery'
      surv   = 'survival time'
      tstatus= 'transplant status'
   ;
/*
   Stanford Heart Transplant Data
   Taken from "The Statistical Analysis of Failure Time Data" by 
   Kalbfleisch and Prentice, Appendix I, pages 230-232.
   The columns are:
      Patient ID
      Year of acceptance
      Age
      Survival status   1=dead  0=alive
      Survival time
      Prior Surgery  1=yes  0=no
      Transplant Status  1=transplanted  0=not transplanted     
*/
   datalines;
 15       68     53    1      1     0    0
 43       70     43    1      2     0    0
 61       71     52    1      2     0    0
 75       72     52    1      2     0    0
  6       68     54    1      3     0    0
 42       70     36    1      3     0    0
 54       71     47    1      3     0    0
 38       70     41    1      5     0    1
 85       73     47    1      5     0    0
  2       68     51    1      6     0    0
103       67     39    1      6     0    0
 12       68     53    1      8     0    0
 48       71     56    1      9     0    0
102       74     40    0     11     0    0
 35       70     43    1     12     0    0
 95       73     40    1     16     0    1
 31       69     54    1     16     0    0
  3       68     54    1     16     0    1
 74       72     29    1     17     0    1
  5       68     20    1     18     0    0
 77       72     41    1     21     0    0
 99       73     49    1     21     0    0
 20       69     55    1     28     0    1
 70       72     52    1     30     0    1
101       74     49    0     31     0    0
 66       72     53    1     32     0    0
 29       69     50    1     35     0    0
 17       68     20    1     36     0    0
 19       68     59    1     37     0    0
  4       68     40    1     39     0    1
100       74     35    0     39     1    1
  8       68     45    1     40     0    0
 44       70     42    1     40     0    0
 16       68     56    1     43     0    1
 45       71     36    1     45     0    1
  1       67     30    1     50     0    0
 22       69     42    1     51     0    1
 39       70     50    1     53     0    1
 10       68     42    1     58     0    1
 35       71     52    1     61     0    1
 37       70     61    1     66     0    1
 68       72     45    1     68     0    1
 60       71     49    1     68     0    1
 62       71     39    1     69     0    0
 28       69     53    1     72     0    1
 47       71     47    1     72     0    1
 32       69     64    1     77     0    1
 65       72     51    1     78     0    1
 83       73     53    1     80     0    1
 13       68     54    1     81     0    1
  9       68     47    1     85     0    0
 73       72     56    1     90     0    1
 79       72     53    1     96     0    1
 36       70     48    1    100     0    1
 32       71     41    1    102     0    0
 98       73     28    0    109     0    1
 87       73     46    1    110     0    1
 97       73     23    0    131     0    1
 37       71     41    1    149     0    0
 11       68     47    1    153     0    1
 94       73     43    1    165     1    1
 96       73     26    0    180     0    1
 90       73     52    1    186     1    1
 53       71     47    1    188     0    1
 89       73     51    1    207     0    1
 24       69     51    1    219     0    1
 27       69      8    1    263     0    0
 93       73     47    0    265     0    1
 51       71     48    1    285     0    1
 67       73     19    1    285     0    1
 16       68     49    1    308     0    1
 84       73     42    1    334     0    1
 91       73     47    1    340     0    0
 92       73     44    0    340     0    1
 58       71     47    1    342     1    1
 88       73     54    0    370     0    1
 86       73     48    0    397     0    1
 82       71     29    0    427     0    0
 81       73     52    0    445     0    1
 80       72     46    0    482     1    1
 78       72     48    0    515     0    1
 76       72     52    0    545     1    1
 64       72     48    1    583     1    1
 72       72     26    0    596     0    1
 71       72     47    0    630     0    1
 69       72     47    0    670     0    1
  7       68     50    1    675     0    1
 23       69     58    1    733     0    1
 63       71     32    0    841     0    1
 30       69     44    1    852     0    1
 59       71     41    0    915     0    1
 56       71     38    0    941     0    1
 50       71     45    1    979     1    1
 46       71     48    1    995     1    1
 21       69     43    1   1032     0    1
 49       71     36    0   1141     1    1
 41       70     45    0   1321     1    1
 14       68     53    1   1386     0    1
 26       69     30    0   1400     0    0
 40       70     48    0   1407     1    1
 34       69     40    0   1571     0    1
 33       69     48    0   1586     0    1
 25       69     33    0   1799     0    1
run;

proc print;
run;

proc phreg;
   model surv * cens(0) = age prior tstatus;
   output out=diags xbeta=xb resmart=mart resdev=dev;
run;

proc print data=diags;
run;

proc gplot data=diags;
   plot (mart dev) * xb;
run;
quit;


